/*
 * REXX script to create index.html from a directory of picture files
 *
 * usage: pic2html [/s] html pattern(s)
 *
 *        /s : recurse into directories is forced 
 *             (otherwise only if no index file is found in the directory)
 *        html: name of index.html (which is the default)
 *        pattern(s): *.jpg *.gif (default) or any other filename template
 * 
 * Just use pic2html without arguments if the defaults are what you want.
 *
 * Multiple html files are created if more then 'max_pic' files are
 * found in the directory (index1.html, index2.html, ...).
 *
 * If the directory contains subdirectories, a file frames.html will be 
 * created as an alternative for navigation.
 * 
 */

/*
 *  decrease this if loading of the generated html is too slow
 */
max_pic = 20

call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
call SysLoadFuncs

parse source system . pic2html
if system == "OS/2" then do
    rexx = "call"
    '@echo off'
end
else do
    rexx = "rexx"
end

parse arg html pattern
opt = ''
create_links = 1
prev_filename = ''

if left( html, 1 ) = '/' then do
    parse arg opt html pattern
end
/* say opt html pattern */
if pos( '*', html ) > 0 | pos( '?', html ) > 0 then do
    pattern = html
    html = ''
end

if html = '' then html = 'index.html'
if pattern = '' then pattern = '*.jpg *.gif'

html_org = html
html_alt = ''
index = ''
nav = 'nav.html'
nav_list.0 = 0

call html_init
count = 0

call SysFileTree '*','dirs','D','*****','*****'
if dirs.0 >= 1 then 
    call SysStemSort 'dirs.','A','I',,,38,100

do i = 1 to dirs.0
    if create_links then do
        call links
        create_links = 0
    end
    parse var dirs.i datum zeit size attribute dir dummy
    dir = filespec( "NAME", dir )
    if stream( dir'\'html_org, 'C', 'QUERY EXISTS' ) = '' | opt = '/s' then 
    do
        /* say dir */
        'cd' dir
        rexx pic2html opt html_org pattern
        'cd ..'
    end
    if stream( dir'\'html_org, 'C', 'QUERY EXISTS' ) <> '' then do
        ref = dir'/'html_org
        do pp = 1 to words( pattern ) until datei.0 <> 0
            call SysFileTree dir'\'word( pattern, pp ),,
                 'datei','F','*****','*****'
        end
        if datei.0 >= 1 then do
            call SysStemSort 'datei.','A','I',,,38,100
            count = count + 1
            if count > max_pic then do
                call html_init
                call links
            end
            call lineout html, ''
            call lineout html, '<H1><A HREF="'ref'" TARGET="BILDER">'ref ||,
                               '</A></H1>'
            call lineout html, datei.0 'Dateien<BR>'
            parse var datei.1 datum zeit size attribute filename dummy
            filename = filespec( "NAME", filename )
            if filename = html then do
                parse var datei.2 datum zeit size attribute filename dummy
                filename = filespec( "NAME", filename )
            end
            filename = dir'/'filename
            /* call lineout html, '<H2>' || filename || '</H2><BR>' */
            call lineout html, '<A HREF="'ref'" TARGET="BILDER">'
            call lineout html, '<IMG SRC="'filename'"',
                               'BORDER=2 HEIGHT=300></A><BR><HR>'
        end 
        else do
            call lineout html, ''
            line = '<A HREF="'ref'">'ref'</A>'
            if stream( dir'\frames.html', 'C', 'QUERY EXISTS' ) <> '' then do
                call lineout html, '<H1>'line
                call lineout html, '    <A HREF="'dir'/frames.html"',
                                   'TARGET="_top">[frames]</A></H1>'
            end
            else do
                call lineout html, '<H1>'line'</H1>'
            end
        end

    end
    /* say filename result */
end

do pp = 1 to words( pattern )

    call SysFileTree word( pattern, pp ),'datei','F','*****','*****'
    if datei.0 >= 1 then
        call SysStemSort 'datei.','A','I',,,38,100
    filename = ''

    do i = 1 to datei.0
        prev_filename = filename
        parse var datei.i datum zeit size attribute filename dummy
        filename = filespec( "NAME", filename )
        if i < datei.0 then do
            i1 = i + 1
            parse var datei.i1 . . . . next_filename .
            next_filename = filespec( "NAME", next_filename )
        end
        if filename <> html then do
            count = count + 1
            if count > max_pic then do
                call html_init
                create_links = 1
            end
            call lineout html, ''
            call lineout html, '<A NAME="'filename'">'
            call lineout html, '<H2>'
            if create_links then do
                call links
                create_links = 0
            end
            else do
                call lineout html, '<A HREF="#'prev_filename'">[prev]</A>'
            end
            ref = ''
            if i < datei.0 then do
                ref = '#'next_filename
                if count = max_pic then do
                    next_index = index + 1
                    ii = lastpos( '.', html_org ) - 1
                    if ii < 0 then ii = length( html_org )
                    ref = insert( next_index, html_org, ii ) || ref
                end
                call lineout html, '<A HREF="'ref'">[next]</A>'
            end
            call lineout html, '&nbsp;'filename'</H2>'
            line = '<IMG SRC="'filename'" BORDER="0">'
            if ref <> '' then do
                line = '<A HREF="'ref'">'line'</A>'
            end
            call lineout html, line'<BR>'
        end
        /* say filename result */
    end
end

call html_exit

if dirs.0 > 0 then do
    frames = 'frames.html'
    'if exist' frames 'del' frames
    call stream frames, 'C', 'OPEN WRITE'
    call lineout frames, '<HTML>'
    call SysFileTree frames,'frame_info','F','*****','*****'
    call SysStemSort 'frame_info.','A','I',,,38,100
    frame_title = word( frame_info.1, 5 );
    frame_title = filespec( 'path', frame_title );
    call lineout frames, '<HEAD>'
    call lineout frames, '<TITLE>'frame_title'</TITLE>'
    call lineout frames, '</HEAD>'
    call lineout frames, '<FRAMESET COLS="35%,*" FRAMEBORDER=YES>'
    if nav_list.0 > 1 then do
        size = nav_list.0 * 4
        if size > 30 then size = 30
        call lineout frames, '  <FRAMESET ROWS="*,'size'%" FRAMEBORDER=YES>'
        call lineout frames, '    <FRAME SRC="'html_org'" NAME="links">'
        call lineout frames, '    <FRAME SRC="'nav'" NAME="nav">'
        call lineout frames, '  </FRAMESET>'
    end
    else do
        call lineout frames, '  <FRAME SRC="'html_org'" NAME="links">'
    end
    call lineout frames, '  <FRAME SRC="about:blank" NAME="BILDER">'
    call lineout frames, '</FRAMESET>'
    call lineout frames, '</HTML>'
    call stream frames, 'C', 'CLOSE'

    'if exist' nav 'del' nav
    if nav_list.0 > 1 then do
        call stream nav, 'C', 'OPEN WRITE'
        call lineout nav, '<HTML>'
        call lineout nav, '<HEAD>'
        call lineout nav, '<TITLE>Navigation</TITLE>'
        call lineout nav, '<BODY>'
        do i = 1 to nav_list.0
            call lineout nav,,
                 '<A HREF="'nav_list.i'" TARGET="links">'nav_list.i'</A><BR>'
        end
        call lineout nav, '</BODY>'
        call lineout nav, '</HEAD>'
        call lineout nav, '</HTML>'
        call stream nav, 'C', 'CLOSE'
    end
end

return 0

links:
    if stream( 'frames.html', 'C', 'QUERY EXISTS' ) <> '' then do
        call lineout html, '<A HREF="frames.html" target="_top">' ||,
                            '[frames]</A>'
    end
    if html_alt = html then do
        if stream( '..\frames.html', 'C', 'QUERY EXISTS' ) <> '' then do
            call lineout html, '<A HREF="../frames.html" target="_top">' ||,
                               '[back]</A>'
        end
    end
    else do
        if html_alt = '' then do
            if stream( '..\frames.html', 'C', 'QUERY EXISTS' ) <> '' then do
                call lineout html, '<A HREF="../frames.html" target="_top">' ||,
                                   '[back]</A>'
            end
        end
        else do
            if prev_filename = '' then do
                call lineout html, '<A HREF="'html_alt'">[back]</A>'
            end
            else do
                call lineout html, '<A HREF="'html_alt'#'prev_filename ||,
                                   '">[prev]</A>'
            end
        end
    end
    if html_neu \= html then do
        call lineout html, '<A HREF="'html_neu'">['html_neu']</A>'
    end
    return 0

html_exit:
    call lineout html, ''
    call lineout html, '<BR><BR>'
    call links

    call lineout html, '</BODY>'
    call lineout html, '</HTML>'

    r = stream( html, 'C', 'CLOSE' )
    return 0

html_init:
    if index \= '' then do
        index = index + 1
        ii = lastpos( '.', html_org ) - 1
        if ii < 0 then ii = length( html_org )
        html_neu = insert( index, html_org, ii )
        /* say html_neu */
        call html_exit
        html_alt = html
        html = html_neu
    end
    else do
        html = html_org
        html_neu = html
        index = 0
    end
    j = index + 1
    nav_list.0 = j
    nav_list.j = html
    /* say nav_list.0 ':' nav_list.j */

    'if exist' html 'del' html
    r = stream( html, 'C', 'OPEN WRITE' )

    call lineout html, '<HTML>'
    call SysFileTree html,'title_info','F','*****','*****'
    title = word( title_info.1, 5 );
    say title
    title = filespec( 'path', title );
    call lineout html, '<HEAD>'
    call lineout html, '<TITLE>'title'</TITLE>'
    call lineout html, '<STYLE>'
    call lineout html, '  H1 { font-size:13pt; font-weight:bold',
                       ' margin-top:2px; margin-bottom:2px; }'
    call lineout html, '  H2 { font-size:12pt; font-weight:normal',
                       ' margin-top:0px; margin-bottom:2px; }'
    call lineout html, '</STYLE>'
    call lineout html, '</HEAD>'
    call lineout html, '<BODY>'

    count = 1
    return 0


